@@ -1,3 +1,4 @@
+pub use entity::FetchEntity;
 pub use option_read::FetchOptionRead;
 pub use option_write::FetchOptionWrite;
 pub use read::FetchRead;
@@ -5,6 +6,7 @@ pub use write::FetchWrite;
 
 use crate::{Entity, Registry};
 
+mod entity;
 mod option_read;
 mod option_write;
 mod read;
